@@ -4,8 +4,7 @@ let _ = Mltop.add_known_module "coq-core.plugins.number_string_notation"
  
 
 open Notation
-open Number
-open String_notation
+open Number_string
 open Pp
 open Stdarg
 open Pcoq.Prim
@@ -57,7 +56,7 @@ let (wit_number_string_mapping, number_string_mapping) = Vernacextend.vernac_arg
                                                            ((Pcoq.Symbol.nterm reference)))
                                                            (fun n' _ _ n _
                                                            loc -> 
-# 54 "plugins/syntax/g_number_string.mlg"
+# 53 "plugins/syntax/g_number_string.mlg"
                                                    true, n, n' 
                                                                   ));
                                                          (Pcoq.Production.make
@@ -70,12 +69,12 @@ let (wit_number_string_mapping, number_string_mapping) = Vernacextend.vernac_arg
                                                           ((Pcoq.Symbol.nterm reference)))
                                                           (fun n' _ n loc ->
                                                           
-# 53 "plugins/syntax/g_number_string.mlg"
+# 52 "plugins/syntax/g_number_string.mlg"
                                            false, n, n' 
                                                           ))]);
                                                          Vernacextend.arg_printer = fun env sigma -> 
                                                          
-# 52 "plugins/syntax/g_number_string.mlg"
+# 51 "plugins/syntax/g_number_string.mlg"
                pr_number_string_mapping 
                                                          ;
                                                          }
@@ -106,12 +105,12 @@ let (wit_number_string_via, number_string_via) = Vernacextend.vernac_argument_ex
                                                                    ())])) false)))
                                                                    ((Pcoq.Symbol.token (Pcoq.terminal "]"))))
                                                    (fun _ l _ _ n _ loc -> 
-# 59 "plugins/syntax/g_number_string.mlg"
+# 58 "plugins/syntax/g_number_string.mlg"
                                                                                           n, l 
                                                                     ))]);
                                                  Vernacextend.arg_printer = fun env sigma -> 
                                                  
-# 58 "plugins/syntax/g_number_string.mlg"
+# 57 "plugins/syntax/g_number_string.mlg"
                pr_number_string_via 
                                                  ;
                                                  }
@@ -125,7 +124,7 @@ let (wit_number_modifier, number_modifier) = Vernacextend.vernac_argument_extend
                                                (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                                ((Pcoq.Symbol.nterm number_string_via)))
                                                (fun v loc -> 
-# 66 "plugins/syntax/g_number_string.mlg"
+# 65 "plugins/syntax/g_number_string.mlg"
                                 Via v 
                                                              ));
                                              (Pcoq.Production.make
@@ -136,7 +135,7 @@ let (wit_number_modifier, number_modifier) = Vernacextend.vernac_argument_extend
                                                               ((Pcoq.Symbol.token (Pcoq.terminal "after"))))
                                                               ((Pcoq.Symbol.nterm bignat)))
                                               (fun n _ _ loc -> 
-# 65 "plugins/syntax/g_number_string.mlg"
+# 64 "plugins/syntax/g_number_string.mlg"
                                         After (Abstract (NumTok.UnsignedNat.of_string n)) 
                                                                 ));
                                              (Pcoq.Production.make
@@ -147,12 +146,12 @@ let (wit_number_modifier, number_modifier) = Vernacextend.vernac_argument_extend
                                                               ((Pcoq.Symbol.token (Pcoq.terminal "after"))))
                                                               ((Pcoq.Symbol.nterm bignat)))
                                               (fun waft _ _ loc -> 
-# 64 "plugins/syntax/g_number_string.mlg"
+# 63 "plugins/syntax/g_number_string.mlg"
                                           After (Warning (NumTok.UnsignedNat.of_string waft)) 
                                                                    ))]);
                                              Vernacextend.arg_printer = fun env sigma -> 
                                              
-# 63 "plugins/syntax/g_number_string.mlg"
+# 62 "plugins/syntax/g_number_string.mlg"
                pr_number_modifier 
                                              ;
                                              }
@@ -180,12 +179,12 @@ let (wit_number_options, number_options) = Vernacextend.vernac_argument_extend ~
                                                                    (fun _ l _
                                                                    loc -> 
                                                                    
-# 71 "plugins/syntax/g_number_string.mlg"
+# 70 "plugins/syntax/g_number_string.mlg"
                                                        l 
                                                                    ))]);
                                            Vernacextend.arg_printer = fun env sigma -> 
                                            
-# 70 "plugins/syntax/g_number_string.mlg"
+# 69 "plugins/syntax/g_number_string.mlg"
                pr_number_options 
                                            ;
                                            }
@@ -206,12 +205,12 @@ let (wit_string_option, string_option) = Vernacextend.vernac_argument_extend ~pl
                                                                     (fun _ v
                                                                     _ loc ->
                                                                     
-# 76 "plugins/syntax/g_number_string.mlg"
+# 75 "plugins/syntax/g_number_string.mlg"
                                         v 
                                                                     ))]);
                                          Vernacextend.arg_printer = fun env sigma -> 
                                          
-# 75 "plugins/syntax/g_number_string.mlg"
+# 74 "plugins/syntax/g_number_string.mlg"
                pr_string_option 
                                          ;
                                          }
@@ -230,11 +229,14 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.numbe
                                                                    Vernacextend.TyNil)))))))), 
          (let coqpp_body ty f g nl sc
          locality = Vernactypes.vtdefault (fun () -> 
-# 83 "plugins/syntax/g_number_string.mlg"
+# 82 "plugins/syntax/g_number_string.mlg"
       vernac_number_notation (Locality.make_module_locality locality) ty f g (Option.default [] nl) sc 
                     ) in fun ty
          f g nl sc ?loc ~atts () -> coqpp_body ty f g nl sc
-         (Attributes.parse Attributes.locality atts)), None))]
+         (Attributes.parse 
+# 79 "plugins/syntax/g_number_string.mlg"
+                   Attributes.locality
+          atts)), None))]
 
 let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.number_string_notation") ~command:"StringNotation" ~classifier:(fun _ -> Vernacextend.classify_as_sideeff) ?entry:None 
          [(Vernacextend.TyML (false, Vernacextend.TyTerminal ("String", 
@@ -249,9 +251,12 @@ let () = Vernacextend.static_vernac_extend ~plugin:(Some "coq-core.plugins.numbe
                                                                    Vernacextend.TyNil)))))))), 
          (let coqpp_body ty f g o sc
          locality = Vernactypes.vtdefault (fun () -> 
-# 89 "plugins/syntax/g_number_string.mlg"
+# 88 "plugins/syntax/g_number_string.mlg"
       vernac_string_notation (Locality.make_module_locality locality) ty f g o sc 
                     ) in fun ty
          f g o sc ?loc ~atts () -> coqpp_body ty f g o sc
-         (Attributes.parse Attributes.locality atts)), None))]
+         (Attributes.parse 
+# 86 "plugins/syntax/g_number_string.mlg"
+                   Attributes.locality
+          atts)), None))]
 
