@@ -1,12 +1,13 @@
 
-# 11 "vernac/g_proofs.mlg"
+# 13 "vernac/g_proofs.mlg"
  
 
-open Glob_term
 open Constrexpr
 open Vernacexpr
 open Hints
 
+module C = Constr
+
 open Pcoq
 open Pcoq.Prim
 open Pcoq.Constr
@@ -14,24 +15,23 @@ open Pvernac.Vernac_
 
 let thm_token = G_vernac.thm_token
 
-let hint = Entry.create "hint"
+let hint = Entry.make "hint"
 
 let warn_deprecated_focus =
-  CWarnings.create ~name:"deprecated-focus" ~category:"deprecated"
-         (fun () ->
-           Pp.strbrk
-             "The Focus command is deprecated; use bullets or focusing brackets instead"
-         )
+  CWarnings.create ~name:"deprecated-focus" ~category:Deprecation.Version.v8_8
+    Pp.(function
+      | None ->
+        strbrk "The Focus command is deprecated; use bullets or focusing brackets instead."
+      | Some n ->
+        str "The Focus command is deprecated;" ++ spc ()
+        ++ str "use '" ++ int n ++ str ": {' instead.")
 
-let warn_deprecated_focus_n n =
-  CWarnings.create ~name:"deprecated-focus" ~category:"deprecated"
-         (fun () ->
-           Pp.(str "The Focus command is deprecated;" ++ spc ()
-               ++ str "use '" ++ int n ++ str ": {' instead")
-         )
+let warn_deprecated_focus_n ?loc n = warn_deprecated_focus ?loc (Some n)
+
+let warn_deprecated_focus ?loc () = warn_deprecated_focus ?loc None
 
 let warn_deprecated_unfocus =
-  CWarnings.create ~name:"deprecated-unfocus" ~category:"deprecated"
+  CWarnings.create ~name:"deprecated-unfocus" ~category:Deprecation.Version.v8_8
          (fun () -> Pp.strbrk "The Unfocus command is deprecated")
 
 
@@ -56,16 +56,16 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                    (fun id
                                                                    loc -> 
                                                                    
-# 53 "vernac/g_proofs.mlg"
+# 55 "vernac/g_proofs.mlg"
                                       id 
                                                                    )])))))
                                   (fun l _ loc -> 
-# 53 "vernac/g_proofs.mlg"
+# 55 "vernac/g_proofs.mlg"
                                                   l 
                                                   );
                                  Pcoq.Production.make (Pcoq.Rule.stop)
                                  (fun loc -> 
-# 52 "vernac/g_proofs.mlg"
+# 54 "vernac/g_proofs.mlg"
            [] 
                                              )])]))
         in let () =
@@ -79,7 +79,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                             ((Pcoq.Symbol.nterm opt_hintbases)))
                             (fun dbnames h _ loc -> 
 # 107 "vernac/g_proofs.mlg"
-            VernacHints (dbnames, h) 
+            VernacSynPure (VernacHints (dbnames, h)) 
                                                     );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
@@ -93,7 +93,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.nterm opt_hintbases)))
                            (fun dbnames ids _ _ loc -> 
 # 105 "vernac/g_proofs.mlg"
-            VernacRemoveHints (dbnames, ids) 
+            VernacSynPure (VernacRemoveHints (dbnames, ids)) 
                                                        );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
@@ -123,15 +123,25 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                )])))
                            (fun b id _ _ loc -> 
 # 103 "vernac/g_proofs.mlg"
-              VernacCreateHintDb (id, b) 
+              VernacSynPure (VernacCreateHintDb (id, b)) 
                                                 );
                            Pcoq.Production.make
+                           (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
+                                                           ((Pcoq.Symbol.token (Tok.PIDENT (Some
+                                                           ("Validate"))))))
+                                           ((Pcoq.Symbol.token (Tok.PIDENT (Some
+                                           ("Proof"))))))
+                           (fun _ _ loc -> 
+# 99 "vernac/g_proofs.mlg"
+                                             VernacSynPure VernacValidateProof 
+                                           );
+                           Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Guarded"))))))
                            (fun _ loc -> 
-# 99 "vernac/g_proofs.mlg"
-                             VernacCheckGuard 
+# 98 "vernac/g_proofs.mlg"
+                             VernacSynPure VernacCheckGuard 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
@@ -142,8 +152,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Match"))))))
                                            ((Pcoq.Symbol.nterm reference)))
                            (fun id _ _ loc -> 
-# 98 "vernac/g_proofs.mlg"
-                                                         VernacShow (ShowMatch id) 
+# 97 "vernac/g_proofs.mlg"
+                                                         VernacSynPure (VernacShow (ShowMatch id)) 
                                               );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -152,8 +162,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Intros"))))))
                            (fun _ _ loc -> 
-# 97 "vernac/g_proofs.mlg"
-                                          VernacShow (ShowIntros true) 
+# 96 "vernac/g_proofs.mlg"
+                                          VernacSynPure (VernacShow (ShowIntros true)) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -162,8 +172,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Intro"))))))
                            (fun _ _ loc -> 
-# 96 "vernac/g_proofs.mlg"
-                                         VernacShow (ShowIntros false) 
+# 95 "vernac/g_proofs.mlg"
+                                         VernacSynPure (VernacShow (ShowIntros false)) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -172,8 +182,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Proof"))))))
                            (fun _ _ loc -> 
-# 95 "vernac/g_proofs.mlg"
-                                         VernacShow ShowProof 
+# 94 "vernac/g_proofs.mlg"
+                                         VernacSynPure (VernacShow ShowProof) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -182,8 +192,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Conjectures"))))))
                            (fun _ _ loc -> 
-# 94 "vernac/g_proofs.mlg"
-                                               VernacShow ShowProofNames 
+# 93 "vernac/g_proofs.mlg"
+                                               VernacSynPure (VernacShow ShowProofNames) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -192,8 +202,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Universes"))))))
                            (fun _ _ loc -> 
-# 93 "vernac/g_proofs.mlg"
-                                             VernacShow ShowUniverses 
+# 92 "vernac/g_proofs.mlg"
+                                             VernacSynPure (VernacShow ShowUniverses) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -202,8 +212,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Existentials"))))))
                            (fun _ _ loc -> 
-# 92 "vernac/g_proofs.mlg"
-                                                VernacShow ShowExistentials 
+# 91 "vernac/g_proofs.mlg"
+                                                VernacSynPure (VernacShow ShowExistentials) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -211,8 +221,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Show"))))))
                                            ((Pcoq.Symbol.nterm ident)))
                            (fun id _ loc -> 
-# 91 "vernac/g_proofs.mlg"
-                                      VernacShow (ShowGoal (GoalId id)) 
+# 90 "vernac/g_proofs.mlg"
+                                      VernacSynPure (VernacShow (ShowGoal (GoalId id))) 
                                             );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -220,33 +230,33 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Show"))))))
                                            ((Pcoq.Symbol.nterm natural)))
                            (fun n _ loc -> 
-# 90 "vernac/g_proofs.mlg"
-                                       VernacShow (ShowGoal (NthGoal n)) 
+# 89 "vernac/g_proofs.mlg"
+                                       VernacSynPure (VernacShow (ShowGoal (NthGoal n))) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Show"))))))
                            (fun _ loc -> 
-# 89 "vernac/g_proofs.mlg"
-                          VernacShow (ShowGoal OpenSubgoals) 
+# 88 "vernac/g_proofs.mlg"
+                          VernacSynPure (VernacShow (ShowGoal OpenSubgoals)) 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Unfocused"))))))
                            (fun _ loc -> 
-# 88 "vernac/g_proofs.mlg"
-                               VernacUnfocused 
+# 87 "vernac/g_proofs.mlg"
+                               VernacSynPure VernacUnfocused 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Unfocus"))))))
                            (fun _ loc -> 
-# 86 "vernac/g_proofs.mlg"
+# 85 "vernac/g_proofs.mlg"
            warn_deprecated_unfocus ~loc ();
-         VernacUnfocus 
+         VernacSynPure VernacUnfocus 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -254,18 +264,18 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Focus"))))))
                                            ((Pcoq.Symbol.nterm natural)))
                            (fun n _ loc -> 
-# 83 "vernac/g_proofs.mlg"
-           warn_deprecated_focus_n n ~loc ();
-         VernacFocus (Some n) 
+# 82 "vernac/g_proofs.mlg"
+           warn_deprecated_focus_n n ~loc;
+         VernacSynPure (VernacFocus (Some n)) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Focus"))))))
                            (fun _ loc -> 
-# 80 "vernac/g_proofs.mlg"
+# 79 "vernac/g_proofs.mlg"
            warn_deprecated_focus ~loc ();
-         VernacFocus None 
+         VernacSynPure (VernacFocus None) 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
@@ -276,8 +286,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("To"))))))
                                            ((Pcoq.Symbol.nterm natural)))
                            (fun n _ _ loc -> 
-# 78 "vernac/g_proofs.mlg"
-                                                   VernacUndoTo n 
+# 77 "vernac/g_proofs.mlg"
+                                                   VernacSynPure (VernacUndoTo n) 
                                              );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -285,24 +295,24 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Undo"))))))
                                            ((Pcoq.Symbol.nterm natural)))
                            (fun n _ loc -> 
-# 77 "vernac/g_proofs.mlg"
-                                       VernacUndo n 
+# 76 "vernac/g_proofs.mlg"
+                                       VernacSynPure (VernacUndo n) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Undo"))))))
                            (fun _ loc -> 
-# 76 "vernac/g_proofs.mlg"
-                          VernacUndo 1 
+# 75 "vernac/g_proofs.mlg"
+                          VernacSynPure (VernacUndo 1) 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Restart"))))))
                            (fun _ loc -> 
-# 75 "vernac/g_proofs.mlg"
-                             VernacRestart 
+# 74 "vernac/g_proofs.mlg"
+                             VernacSynPure VernacRestart 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -310,16 +320,16 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Defined"))))))
                                            ((Pcoq.Symbol.nterm identref)))
                            (fun id _ loc -> 
-# 74 "vernac/g_proofs.mlg"
-            VernacEndProof (Proved (Transparent,Some id)) 
+# 73 "vernac/g_proofs.mlg"
+            VernacSynPure (VernacEndProof (Proved (Transparent,Some id))) 
                                             );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Defined"))))))
                            (fun _ loc -> 
-# 72 "vernac/g_proofs.mlg"
-                             VernacEndProof (Proved (Transparent,None)) 
+# 71 "vernac/g_proofs.mlg"
+                             VernacSynPure (VernacEndProof (Proved (Transparent,None))) 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -327,45 +337,25 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Save"))))))
                                            ((Pcoq.Symbol.nterm identref)))
                            (fun id _ loc -> 
-# 71 "vernac/g_proofs.mlg"
-            VernacEndProof (Proved (Opaque, Some id)) 
+# 70 "vernac/g_proofs.mlg"
+            VernacSynPure (VernacEndProof (Proved (Opaque, Some id))) 
                                             );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Qed"))))))
                            (fun _ loc -> 
-# 69 "vernac/g_proofs.mlg"
-                         VernacEndProof (Proved (Opaque,None)) 
+# 68 "vernac/g_proofs.mlg"
+                         VernacSynPure (VernacEndProof (Proved (Opaque,None))) 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Admitted"))))))
                            (fun _ loc -> 
-# 68 "vernac/g_proofs.mlg"
-                              VernacEndProof Admitted 
-                                         );
-                           Pcoq.Production.make
-                           (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
-                                                           (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (Tok.PIDENT (Some
-                                                           ("Existential"))))))
-                                                           ((Pcoq.Symbol.nterm natural)))
-                                           ((Pcoq.Symbol.nterm constr_body)))
-                           (fun c n _ loc -> 
 # 67 "vernac/g_proofs.mlg"
-            VernacSolveExistential (n,c) 
-                                             );
-                           Pcoq.Production.make
-                           (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
-                                                           ((Pcoq.Symbol.token (Tok.PIDENT (Some
-                                                           ("Abort"))))))
-                                           ((Pcoq.Symbol.nterm identref)))
-                           (fun id _ loc -> 
-# 65 "vernac/g_proofs.mlg"
-                                          VernacAbort (Some id) 
-                                            );
+                              VernacSynPure (VernacEndProof Admitted) 
+                                         );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
@@ -373,16 +363,16 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("All"))))))
                            (fun _ _ loc -> 
-# 64 "vernac/g_proofs.mlg"
-                                        VernacAbortAll 
+# 66 "vernac/g_proofs.mlg"
+                                        VernacSynPure VernacAbortAll 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Abort"))))))
                            (fun _ loc -> 
-# 63 "vernac/g_proofs.mlg"
-                           VernacAbort None 
+# 65 "vernac/g_proofs.mlg"
+                           VernacSynPure VernacAbort 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -390,8 +380,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Proof"))))))
                                            ((Pcoq.Symbol.nterm lconstr)))
                            (fun c _ loc -> 
-# 62 "vernac/g_proofs.mlg"
-                                        VernacExactProof c 
+# 64 "vernac/g_proofs.mlg"
+                                        VernacSynPure (VernacExactProof c) 
                                            );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
@@ -402,8 +392,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Mode"))))))
                                            ((Pcoq.Symbol.nterm string)))
                            (fun mn _ _ loc -> 
-# 61 "vernac/g_proofs.mlg"
-                                                        VernacProofMode mn 
+# 63 "vernac/g_proofs.mlg"
+                                                        VernacSynterp (VernacProofMode mn) 
                                               );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.next 
@@ -414,16 +404,16 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("using"))))))
                                            ((Pcoq.Symbol.nterm G_vernac.section_subset_expr)))
                            (fun l _ _ loc -> 
-# 60 "vernac/g_proofs.mlg"
-            VernacProof (None,Some l) 
+# 62 "vernac/g_proofs.mlg"
+            VernacSynPure (VernacProof (None,Some l)) 
                                              );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.stop)
                                            ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                            ("Proof"))))))
                            (fun _ loc -> 
-# 58 "vernac/g_proofs.mlg"
-                           VernacProof (None,None) 
+# 60 "vernac/g_proofs.mlg"
+                           VernacSynPure (VernacProof (None,None)) 
                                          );
                            Pcoq.Production.make
                            (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
@@ -431,8 +421,8 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                            ("Goal"))))))
                                            ((Pcoq.Symbol.nterm lconstr)))
                            (fun c _ loc -> 
-# 57 "vernac/g_proofs.mlg"
-          VernacDefinition (Decls.(NoDischarge, Definition), ((CAst.make ~loc Names.Anonymous), None), ProveBody ([], c)) 
+# 59 "vernac/g_proofs.mlg"
+          VernacSynPure (VernacDefinition (Decls.(NoDischarge, Definition), ((CAst.make ~loc Names.Anonymous), None), ProveBody ([], c))) 
                                            )]))
         in let () = assert (Pcoq.Entry.is_empty reference_or_constr)
         in
@@ -465,7 +455,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                   ("Constructors"))))))
                                                   ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm global)))))
                                   (fun lc _ loc -> 
-# 129 "vernac/g_proofs.mlg"
+# 131 "vernac/g_proofs.mlg"
                                                      HintsConstructors lc 
                                                    );
                                  Pcoq.Production.make
@@ -474,7 +464,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                  ("Unfold"))))))
                                                  ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm global)))))
                                  (fun lqid _ loc -> 
-# 128 "vernac/g_proofs.mlg"
+# 130 "vernac/g_proofs.mlg"
                                                  HintsUnfold lqid 
                                                     );
                                  Pcoq.Production.make
@@ -485,7 +475,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                  ((Pcoq.Symbol.nterm global)))
                                                  ((Pcoq.Symbol.nterm mode)))
                                  (fun m l _ loc -> 
-# 127 "vernac/g_proofs.mlg"
+# 129 "vernac/g_proofs.mlg"
                                                 HintsMode (l, m) 
                                                    );
                                  Pcoq.Production.make
@@ -494,7 +484,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                  ("Opaque"))))))
                                                  ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm global)))))
                                  (fun lc _ loc -> 
-# 126 "vernac/g_proofs.mlg"
+# 128 "vernac/g_proofs.mlg"
                                                HintsTransparency (HintsReferences lc, false) 
                                                   );
                                  Pcoq.Production.make
@@ -503,10 +493,30 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                  ("Transparent"))))))
                                                  ((Pcoq.Symbol.list1 ((Pcoq.Symbol.nterm global)))))
                                  (fun lc _ loc -> 
-# 125 "vernac/g_proofs.mlg"
+# 127 "vernac/g_proofs.mlg"
                                                     HintsTransparency (HintsReferences lc, true) 
                                                   );
                                  Pcoq.Production.make
+                                 (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
+                                                                 ((Pcoq.Symbol.token (Tok.PIDENT (Some
+                                                                 ("Projections"))))))
+                                                 ((Pcoq.Symbol.token (Tok.PIDENT (Some
+                                                 ("Opaque"))))))
+                                 (fun _ _ loc -> 
+# 126 "vernac/g_proofs.mlg"
+                                                 HintsTransparency (HintsProjections, false) 
+                                                 );
+                                 Pcoq.Production.make
+                                 (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
+                                                                 ((Pcoq.Symbol.token (Tok.PIDENT (Some
+                                                                 ("Projections"))))))
+                                                 ((Pcoq.Symbol.token (Tok.PIDENT (Some
+                                                 ("Transparent"))))))
+                                 (fun _ _ loc -> 
+# 125 "vernac/g_proofs.mlg"
+                                                      HintsTransparency (HintsProjections, true) 
+                                                 );
+                                 Pcoq.Production.make
                                  (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                                  ((Pcoq.Symbol.token (Tok.PIDENT (Some
                                                                  ("Constants"))))))
@@ -606,15 +616,15 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                   ((Pcoq.Symbol.token (Tok.PKEYWORD (":=")))))
                                                   ((Pcoq.Symbol.nterm lconstr)))
                                   (fun c _ t _ loc -> 
-# 133 "vernac/g_proofs.mlg"
-                                                 CAst.make ~loc @@ CCast(c,CastConv t) 
+# 135 "vernac/g_proofs.mlg"
+                                                 CAst.make ~loc @@ CCast(c,Some C.DEFAULTcast, t) 
                                                       );
                                  Pcoq.Production.make
                                  (Pcoq.Rule.next (Pcoq.Rule.next (Pcoq.Rule.stop)
                                                                  ((Pcoq.Symbol.token (Tok.PKEYWORD (":=")))))
                                                  ((Pcoq.Symbol.nterm lconstr)))
                                  (fun c _ loc -> 
-# 132 "vernac/g_proofs.mlg"
+# 134 "vernac/g_proofs.mlg"
                                c 
                                                  )])]))
         in let () = assert (Pcoq.Entry.is_empty mode) in
@@ -631,7 +641,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                    (fun _
                                                                    loc -> 
                                                                    
-# 138 "vernac/g_proofs.mlg"
+# 140 "vernac/g_proofs.mlg"
                              ModeOutput 
                                                                    );
                                                   Pcoq.Rules.make (Pcoq.Rule.next_norec 
@@ -640,7 +650,7 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                   (fun _
                                                                   loc -> 
                                                                   
-# 137 "vernac/g_proofs.mlg"
+# 139 "vernac/g_proofs.mlg"
                              ModeNoHeadEvar 
                                                                   );
                                                   Pcoq.Rules.make (Pcoq.Rule.next_norec 
@@ -649,11 +659,11 @@ let _ = let opt_hintbases = Pcoq.Entry.make "opt_hintbases"
                                                                   (fun _
                                                                   loc -> 
                                                                   
-# 136 "vernac/g_proofs.mlg"
+# 138 "vernac/g_proofs.mlg"
                              ModeInput 
                                                                   )])))))
                                   (fun l loc -> 
-# 138 "vernac/g_proofs.mlg"
+# 140 "vernac/g_proofs.mlg"
                                                  l 
                                                 )])]))
         in ()
